@@ -49,8 +49,6 @@ using namespace textual;
 using namespace timely;
 using namespace unit_test;
 
-//HOOPLE_STARTUP_CODE;
-
 //#define DEBUG_STRING_TEST
   // uncomment for testing version.
 
@@ -859,6 +857,8 @@ void test_string::run_test_29()
   ASSERT_EQUAL(b, a, "second comparison failed");
 }
 
+#define static_class_name() "test_string"
+
 void standard_sprintf_test(const char *parm_string)
 {
   FUNCDEF("standard_sprintf_test");
@@ -875,6 +875,8 @@ void standard_sprintf_test(const char *parm_string)
       parm_string, parm_string, basis::un_long(rando.inclusive(0, 2998238)));
 }
 
+#undef static_class_name
+
 void test_string::run_test_30()
 {
   // 30th test group checks astring sprintf.
@@ -1278,4 +1280,3 @@ int test_string::execute()
 
 HOOPLE_MAIN(test_string, )
 
-
